==> seedsui-react-5.6.85.tgz: package/lib/TreePicker/Tree/utils/getTreeData.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import HighlightKeyword from "./../../../HighlightKeyword";

// 构建渲染数据, 支持关键字搜索
import { jsx as _jsx } from "react/jsx-runtime";
function getTreeData(_ref) {
  var _originData$, _originData$2;
  var originData = _ref.list,
    onlyLeafCheck = _ref.onlyLeafCheck,
    keyword = _ref.keyword,
    itemRender = _ref.itemRender;
  if (
  // 必须是数组
  !Array.isArray(originData) || !originData.length ||
  // 必须有id和name属性
  !((_originData$ = originData[0]) !== null && _originData$ !== void 0 && _originData$.id) || !((_originData$2 = originData[0]) !== null && _originData$2 !== void 0 && _originData$2.name)) {
    console.error('SeedsUI TreePicker.Tree: list参数不正确');
    return [];
  }
  // 关键字搜索
  var loop = function loop(data) {
    return data.map(function (item) {
      var titleNode = /*#__PURE__*/_jsx(HighlightKeyword, {
        text: item.name,
        keyword: keyword
      });

      // 自定义渲染
      if (typeof itemRender === 'function') {
        var customTitleNode = itemRender(item, {
          keyword: keyword
        });
        if (customTitleNode) {
          titleNode = customTitleNode;
        }
      }
      if (Array.isArray(item.children) && item.children.length) {
        return _objectSpread(_objectSpread({
          disabled: onlyLeafCheck
        }, item), {}, {
          title: titleNode,
          children: loop(item.children)
        });
      }
      return _objectSpread(_objectSpread({}, item), {}, {
        title: titleNode
      });
    });
  };
  return loop(originData);
}
export default getTreeData;

==> seedsui-react-5.6.96.tgz: package/lib/TreePicker/Tree/utils/getTreeData.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import HighlightKeyword from "./../../../HighlightKeyword";

// 构建渲染数据, 支持关键字搜索
import { jsx as _jsx } from "react/jsx-runtime";
function getTreeData(_ref) {
  var _list$, _list$2;
  var list = _ref.list,
    onlyLeafCheck = _ref.onlyLeafCheck,
    keyword = _ref.keyword,
    itemRender = _ref.itemRender,
    _onClick = _ref.onClick;
  if (
  // 必须是数组
  !Array.isArray(list) || !list.length ||
  // 必须有id和name属性
  !((_list$ = list[0]) !== null && _list$ !== void 0 && _list$.id) || !((_list$2 = list[0]) !== null && _list$2 !== void 0 && _list$2.name)) {
    console.error('SeedsUI TreePicker.Tree: list参数不正确');
    return [];
  }
  // 关键字搜索
  var loop = function loop(data) {
    return data.map(function (item) {
      var titleNode = /*#__PURE__*/_jsx("div", {
        className: "rc-tree-title-wrapper",
        onClick: function onClick(e) {
          e.stopPropagation();
          typeof _onClick === 'function' && _onClick(item);
        },
        children: /*#__PURE__*/_jsx(HighlightKeyword, {
          text: item.name,
          keyword: keyword
        })
      });

      // 自定义渲染
      if (typeof itemRender === 'function') {
        var customTitleNode = itemRender(item, {
          keyword: keyword
        });
        if (customTitleNode) {
          titleNode = customTitleNode;
        }
      }
      if (Array.isArray(item.children) && item.children.length) {
        return _objectSpread(_objectSpread({
          disabled: onlyLeafCheck
        }, item), {}, {
          title: titleNode,
          children: loop(item.children)
        });
      }
      return _objectSpread(_objectSpread({}, item), {}, {
        title: titleNode
      });
    });
  };
  return loop(list);
}
export default getTreeData;
